@@ -1,26 +1,8 @@
-## $Id: newFunc.R,v 1.6.2.1 2002/12/27 17:03:09 bates Exp $
-###
 ###       Functions that are used in several parts of the nlme library
 ###                 but do not belong to any specific part
 ###
-### Copyright 1997-2001  Jose C. Pinheiro <jcp@research.bell-labs.com>,
+### Copyright 1997-2003  Jose C. Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
-###
-### This file is part of the nlme library for S and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
 
 allCoef <-
   ## Combines different coefficient vectors into one vector, keeping track
@@ -284,11 +266,9 @@ gsummary <-
 	value[[nm]] <-
 	  as.vector(tapply(as.character(object[[nm]]), groups, FUN[[dClass]]))
         if (inherits(object[,nm], "ordered")) {
-          value[[nm]] <- pruneLevels(ordered(value[,nm],
-                                            levels = levels(object[,nm])))
+          value[[nm]] <- ordered(value[,nm], levels = levels(object[,nm]))[drop = TRUE]
         } else {
-          value[[nm]] <- pruneLevels(factor(value[,nm],
-                                           levels = levels(object[,nm])))
+          value[[nm]] <- factor(value[,nm], levels = levels(object[,nm]))[drop = TRUE]
         }
       }
     }
